@@ -1,4 +1,4 @@
-use eva_common::events::RawStateEventOwned;
+use eva_common::events::{LocalStateEvent, RawStateEventOwned};
 use eva_common::prelude::*;
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use std::fmt;
@@ -290,3 +290,39 @@ impl FromStr for StateProp {
         }
     }
 }
+
+#[derive(Debug, Clone, Serialize, Deserialize)]
+#[serde(deny_unknown_fields)]
+pub struct FullItemState {
+    pub oid: OID,
+    pub status: ItemStatus,
+    pub value: Value,
+    pub act: Option<usize>,
+    pub ieid: IEID,
+    pub t: f64,
+}
+
+impl FullItemState {
+    pub fn from_local_state_event(state: LocalStateEvent, oid: OID) -> Self {
+        Self {
+            oid,
+            status: state.status,
+            value: state.value,
+            act: state.act,
+            ieid: state.ieid,
+            t: state.t,
+        }
+    }
+}
+
+impl From<FullItemState> for LocalStateEvent {
+    fn from(state: FullItemState) -> LocalStateEvent {
+        Self {
+            status: state.status,
+            value: state.value,
+            act: state.act,
+            ieid: state.ieid,
+            t: state.t,
+        }
+    }
+}
